:mod:`modelicares.base`
=======================

.. automodule:: modelicares.base
   :members:
   :undoc-members:
   :exclude-members: ArrowLine

.. autoclass:: modelicares.base.ArrowLine
   :exclude-members: Path
